#!/bin/sh
#
# ossec	Host-based Intrusion Detection System.
#
# chkconfig: - 99 15
# description: OSSEC is an Open Source Host-based \
#              Intrusion Detection System.

# Do not load RH compatibility interface.
WITHOUT_RC_COMPAT=1

# Source function library.
. /etc/init.d/functions

TYPE=
DIRECTORY=

SourceIfNotEmpty /etc/ossec-init.conf

daemons=(agentd maild execd analysisd logcollector remoted syscheckd monitord)
expuser=(_ossec _ossecm root _ossec root _ossecr root _ossec)

case "$TYPE" in
	local)
		start_order="1 2 3 4 6 7"
		stop_order="7 4 6 3 1 2"
		;;
	server)
		start_order="1 2 3 4 5 6 7"
		stop_order="7 4 5 6 3 1 2"
		;;
	agent)
		start_order="2 0 4 6"
		stop_order="4 6 0 2"
		;;
	*)
		echo "Error: wrong installation type in /etc/ossec-init.conf" >&2
		exit 1
		;;
esac

if [ -z "$DIRECTORY" ]; then
	echo "Error: directory name in /etc/ossec-init.conf cannot be empty!" >&2
	exit 1
fi

export PATH="$PATH:$DIRECTORY/bin"

LOCKFILE=/var/lock/subsys/ossec
RETVAL=0


check()
{
	# Start daemons in test configuration mode
	for i in $start_order; do
		"ossec-${daemons[$i]}" -t
		RETVAL=$?
		[ $RETVAL -eq 0 ] || return
	done
}

start()
{
	check
	[ $RETVAL -eq 0 ] || return
	
	for i in $start_order; do
		local name="ossec-${daemons[$i]}"
		
		start_daemon \
			--pidfile "$DIRECTORY/var/run/$name.pid" \
			--lockfile "$LOCKFILE" \
			--expect-user "${expuser[$i]}" \
			-- "$name"
		
		RETVAL=$?
		[ $RETVAL -eq 0 ] || return
	done
}

stop()
{
	for i in $stop_order; do
		local name="ossec-${daemons[$i]}"
		
		stop_daemon \
			--pidfile "$DIRECTORY/var/run/$name.pid" \
			--lockfile "$LOCKFILE" \
			--expect-user "${expuser[$i]}" \
			-- "$name"
		
		RETVAL=$?
		[ $RETVAL -eq 0 ] || return
	done
}

restart()
{
	stop
	start
}

show_status()
{
	for i in $start_order; do
		local name="ossec-${daemons[$i]}"
		
		status \
		--pidfile "$DIRECTORY/var/run/$name.pid" \
		--expect-user "${expuser[$i]}" \
		-- "$name"
	done
}

# See how we were called.
case "$1" in
	check)
		check
		;;
	start)
		start
		;;
	stop)
		stop
		;;
	restart)
		restart
		;;
	condstop)
		if [ -e "$LOCKFILE" ]; then
			stop
		fi
		;;
	condrestart)
		if [ -e "$LOCKFILE" ]; then
			restart
		fi
		;;
	status)
		show_status
		;;
	*)
		msg_usage "${0##*/} {check|start|stop|restart|condstop|condrestart|status}"
		RETVAL=1
esac

exit $RETVAL